#include <cstdio>
#include <iostream>
#include <cassert>
#include <vector>
#include <map>
#include <string>
#include <algorithm>
#include <sstream>
#include "testlib.h"

using namespace std;

int cur_test = -1;
const int GROUPS_CNT = 3;
const int MAXN = 1000;
const int MAXX = 1000;
const int MAXM[GROUPS_CNT] = {0, 1, 100};


string itoa(int x) 
{
    stringstream ss;
    string s;
    ss << x;
    ss >> s;
    return s;
}

int atoi(string s) 
{
    stringstream ss;
    int x;
    ss << s;
    ss >> x;
    return x;
}

void write_test(pair<vector<int>, int> test) 
{
    startTest(cur_test++);
    cerr << cur_test << endl;
    cout << test.first.size() << ' ' << test.second << endl;
    for (int i = 0; i < (int)test.first.size() - 1; i++)
        cout << test.first[i] << ' ';
    cout << test.first.back() << endl;
}

void gen_rand(int n, int m, int k, int maxx = MAXX)
{
    vector<int> p(n);
    for (int i = 0; i < n; i++)
    {
        int a = rnd.next(m, maxx);
        p[i] = a;
        if (i > 0)
            p[i] += p[i - 1];
    }
    for (int i = 0; i < k; i++)
    {
        int ind = rnd.next(n);
        p[ind] = -1;
    }
    write_test({p, m});
}

void gen_rand_incorrect(int n, int m, int maxx)
{
    vector<int> p(n);
    for (int i = 0; i < n; i++)
        p[i] = rnd.next(1, maxx);
    write_test({p, m});
}


void gen_rand_wrong1(int n, int m, int k, int maxx = MAXX)
{
    vector<int> p(n);
    for (int i = 0; i < n; i++)
    {
        p[i] = m;
        if (i > 0)
            p[i] += p[i - 1];
    }
    for (int i = 0; i < k; i++)
    {
        int ind = rnd.next(n);
        while (p[ind] == -1)
            ind = (ind + 1) % n;
        p[ind] = -1;
    }
    int ind = rnd.next(n);
    while (p[ind] == -1)
        ind = (ind + 1) % n;
    p[ind]--;
    write_test({p, m});
}

void gen_rand_wrong(int n, int m, int k, int maxx = MAXX)
{
    vector<int> p(n);
    for (int i = 0; i < n; i++)
    {
        int a = rnd.next(maxx) + 1;
        p[i] = a;
        if (i > 0)
            p[i] += p[i - 1];
    }
    for (int i = 0; i < k; i++)
    {
        int ind = rnd.next(n);
        p[ind] = -1;
    }
    write_test({p, m});
}

void gen_m(int n, int m, int k)
{
    vector<int> p(n);
    for (int i = 0; i < n; i++)
    {
        p[i] = m;
        if (i > 0)
            p[i] += p[i - 1];
    }
    for (int i = 0; i < k; i++)
    {
        int ind = rnd.next(n);
        p[ind] = -1;
    }
    write_test({p, m});
}

void gen_minus1(int n, int m)
{
    vector<int> p(n, -1);
    write_test({p, m});
}


int main(int argc, char * argv[]) 
{
    registerGen(argc, argv, 1);
    cur_test = atoi(argv[1]);
    for (int g = 0; g < GROUPS_CNT; g++)
    {
        if (g < 2)
        {
            gen_rand(10, rnd.next(g, MAXM[g]), 5, 10);
            gen_minus1(5, rnd.next(g, MAXM[g]));
            gen_m(7, rnd.next(g, MAXM[g]), 3);
            gen_rand_wrong(10, rnd.next(g, MAXM[g]), 5, 7);
            gen_rand_wrong1(10, rnd.next(g, MAXM[g]), 5, 5);
            gen_rand_incorrect(10, g, 7);
        }
        for (int i = 0; i < 3; i++)
        {
            int n;
            n = rnd.next(1, MAXN);
            gen_rand(n, rnd.next(g, MAXM[g]), rnd.next(1, n), MAXX);
            n = rnd.next(1, MAXN);
            gen_m(n, rnd.next(g, MAXM[g]), rnd.next(1, n));
            n = rnd.next(1, MAXN);
            gen_rand_wrong(n, rnd.next(g, MAXM[g]), rnd.next(1, n), MAXX);
            n = rnd.next(1, MAXN);
            gen_rand_wrong1(n, rnd.next(g, MAXM[g]), rnd.next(1, n), MAXX);
        }

        gen_rand(MAXN, MAXM[g], MAXN / 2, MAXX);
        gen_minus1(MAXN, MAXM[g]);
        gen_m(MAXN, MAXM[g], MAXN / 2);
        gen_rand_wrong(MAXN, MAXM[g], MAXN / 2, MAXX);
        gen_rand_wrong1(MAXN, MAXM[g], MAXN / 2, MAXX);
        gen_rand_incorrect(MAXN, MAXM[g], MAXX);
        cerr << "END OF GROUP" << endl;
    }
    return 0;
}